@@ -73,15 +73,15 @@ class RelMode(Enum):
         各関係タグの具体例は以下の通りである：
 
         * AND
-            (例) 太郎と花子が学校から<帰った> (ガ格:太郎, ガ格:花子 [and])
+            （例）太郎と花子が学校から<帰った>（ガ格:太郎, ガ格:花子 [and]）
         * OR
-            (例) 私は田園調布か国立に<住みたい> (ガ格:私, ニ格:田園調布, ニ格:国立 [or])
+            （例）私は田園調布か国立に<住みたい>（ガ格:私, ニ格:田園調布, ニ格:国立 [or]）
         * AMBIGUOUS
-            (例) 高知県の橋本知事は…国籍条項を<撤廃する>方針を明らかにした (ガ格:高知県, ガ格:橋本知事 [？], ガ格:不特定:人 [？], ヲ格:条項, 外の関係:方針)
+            （例）高知県の橋本知事は…国籍条項を<撤廃する>方針を明らかにした（ガ格:高知県, ガ格:橋本知事 [？], ガ格:不特定:人 [？], ヲ格:条項, 外の関係:方針）
 
     .. note::
-        target が「なし」の場合、同じタイプの関係タグが任意的要素であることを示す．
-            (例) 太郎は一人で<立っていた> (ガ格:太郎, デ格:一人, デ格:なし [？])
+        target が「なし」の場合，同じタイプの関係タグが任意的要素であることを示す．
+            （例）太郎は一人で<立っていた>（ガ格:太郎, デ格:一人, デ格:なし [？]）
     """
 
     AND = "AND"  #: 関係の対象が並列である．
@@ -94,8 +94,8 @@ class RelTag:
     """関係タグ付きコーパスにおける <rel> タグを表すクラス．"""
 
     PAT: ClassVar[re.Pattern] = re.compile(
-        r'<rel type="(?P<type>\S+?)"( mode="(?P<mode>[^>]+?)")? target="(?P<target>.+?)"( sid="(?P<sid>.*?)" '
-        r'id="(?P<id>\d+?)")?/>'
+        r'<rel type="(?P<type>\S+?)"( mode="(?P<mode>\S+?)")? target="(?P<target>.+?)"'
+        r'( sid="(?P<sid>.*?)" id="(?P<id>\d+?)")?/>'
     )
     type: str
     target: str
@@ -108,7 +108,8 @@ class RelTag:
         ret = f'<rel type="{self.type}"'
         if self.mode is not None:
             ret += f' mode="{self.mode.value}"'
-        ret += f' target="{self.target}"'
+        target = self.target.replace('"', r"\"")  # escape double quotes
+        ret += f' target="{target}"'
         if self.sid is not None:
             assert self.base_phrase_index is not None
             ret += f' sid="{self.sid}" id="{self.base_phrase_index}"'
@@ -122,18 +123,18 @@ class RelTagList(List[RelTag]):
     @classmethod
     def from_fstring(cls, fstring: str) -> "RelTagList":
         """KNP における素性文字列からオブジェクトを作成．"""
-        rels = []
+        rel_tags = []
         for match in RelTag.PAT.finditer(fstring):
-            rels.append(
+            rel_tags.append(
                 RelTag(
                     type=match["type"],
-                    target=match["target"],
+                    target=match["target"].replace(r"\"", '"'),  # unescape double quotes
                     sid=match["sid"],
                     base_phrase_index=int(match["id"]) if match["id"] else None,
                     mode=RelMode(match["mode"]) if match["mode"] else None,
                 )
             )
-        return cls(rels)
+        return cls(rel_tags)
 
     def to_fstring(self) -> str:
         """素性文字列に変換．"""
