@@ -1,5 +1,6 @@
 from .jumanpp import Jumanpp
 from .knp import KNP
+from .kwja import KWJA
 from .senter import RegexSenter
 
-__all__ = ["RegexSenter", "Jumanpp", "KNP"]
+__all__ = ["RegexSenter", "Jumanpp", "KNP", "KWJA"]
