@@ -1,5 +1,6 @@
 from .dependency import DepType
 from .feature import FeatureDict
+from .memo import MemoTag
 from .named_entity import NamedEntity, NamedEntityCategory
 from .semantics import SemanticsDict
 
@@ -9,4 +10,5 @@ __all__ = [
     "SemanticsDict",
     "NamedEntity",
     "NamedEntityCategory",
+    "MemoTag",
 ]
