@@ -25,6 +25,11 @@ class NamedEntityCategory(Enum):
 
     @classmethod
     def has_value(cls, value: str) -> bool:
+        """有効な固有表現カテゴリであれば True．
+
+        Args:
+            value: 固有表現のカテゴリ．
+        """
         return any(value == item.value for item in cls)
 
 
@@ -37,13 +42,14 @@ class NamedEntity:
     category: NamedEntityCategory
     morphemes: List["Morpheme"]
 
-    @property
-    def text(self) -> str:
-        return "".join(m.text for m in self.morphemes)
-
     def __str__(self) -> str:
         return self.text
 
+    @property
+    def text(self) -> str:
+        """固有表現の表層文字列．"""
+        return "".join(m.text for m in self.morphemes)
+
     @classmethod
     def from_fstring(cls, fstring: str, candidate_morphemes: List["Morpheme"]) -> Optional["NamedEntity"]:
         """KNP における素性文字列からオブジェクトを作成．"""
@@ -51,11 +57,11 @@ class NamedEntity:
         if match is None:
             logger.warning(f"{fstring} is not a valid NE fstring")
             return None
-        category = match.group("cat")
+        category: str = match["cat"]
         if not NamedEntityCategory.has_value(category):
             logger.warning(f"{candidate_morphemes[0].sentence.sid}: unknown NE category: {category}")
             return None
-        name = match.group("name")
+        name: str = match["name"].replace(r"\"", '"')
         if (span := cls._find_morpheme_span(name, candidate_morphemes)) is None:
             logger.warning(f"{candidate_morphemes[0].sentence.sid}: morpheme span of '{name}' not found")
             return None
@@ -63,11 +69,12 @@ class NamedEntity:
 
     def to_fstring(self) -> str:
         """素性文字列に変換．"""
-        return f"<NE:{self.category.value}:{self.text}>"
+        escaped_text = self.text.replace('"', r"\"")
+        return f"<NE:{self.category.value}:{escaped_text}>"
 
     @staticmethod
     def _find_morpheme_span(name: str, candidates: List["Morpheme"]) -> Optional[range]:
-        """name にマッチする形態素の範囲を返す．
+        """固有表現の文字列にマッチする形態素の範囲を返す．
 
         Args:
             name: 固有表現の文字列
