@@ -1,15 +1,15 @@
 import re
-from typing import Dict, Union
+from typing import Dict, Optional, Union
 
 
 class SemanticsDict(Dict[str, Union[str, bool]]):
     """形態素の意味情報を表すクラス．"""
 
     NIL = "NIL"
-    PAT = re.compile(rf'(?P<sems>("([^"]|\\")+?")|{NIL})')
+    PAT = re.compile(rf'(?P<sems>("([^\\"]|\\"|\\(?!"))+?")|{NIL})')
     SEM_PAT = re.compile(r"(?P<key>[^:\s]+)(:(?P<value>\S+))?(\s|$)")
 
-    def __init__(self, semantics: Dict[str, Union[str, bool]] = None, is_nil: bool = False):
+    def __init__(self, semantics: Optional[Dict[str, Union[str, bool]]] = None, is_nil: bool = False) -> None:
         if semantics is None:
             semantics = {}
         super().__init__(semantics)
@@ -18,16 +18,19 @@ class SemanticsDict(Dict[str, Union[str, bool]]):
     @classmethod
     def from_sstring(cls, sstring: str) -> "SemanticsDict":
         """意味情報文字列をパースして辞書型に変換する．
-        e.g., "\"代表表記:日本/にほん 地名:国\"" -> {"代表表記": "日本/にほん", "地名": "国"}
+
+        例："代表表記:日本/にほん 地名:国" -> {"代表表記": "日本/にほん", "地名": "国"}
 
         Args:
             sstring: KNP 形式における意味情報文字列．
         """
         is_nil = sstring == cls.NIL
-        semantics = {}
+        semantics: Dict[str, Union[str, bool]] = {}
         if not is_nil:
             for match in cls.SEM_PAT.finditer(sstring.strip('"')):
-                semantics[match.group("key")] = match.group("value") or True
+                semantics[match["key"].replace(r"\"", '"')] = (
+                    match["value"].replace(r"\"", '"') if match["value"] else True
+                )
         return cls(semantics, is_nil)
 
     def to_sstring(self) -> str:
@@ -38,8 +41,9 @@ class SemanticsDict(Dict[str, Union[str, bool]]):
 
     @staticmethod
     def _item_to_sstring(key: str, value: Union[str, bool]) -> str:
-        if value is False:
-            return ""
-        if value is True:
-            return f"{key}"
-        return f"{key}:{value}"
+        escaped_key = key.replace('"', r"\"")
+        if isinstance(value, bool):
+            return escaped_key if value else ""
+        else:
+            escaped_value = value.replace('"', r"\"")
+            return f"{escaped_key}:{escaped_value}"
