@@ -8,7 +8,6 @@ from rhoknp.units.clause import Clause
 from rhoknp.units.morpheme import Morpheme
 from rhoknp.units.phrase import Phrase
 from rhoknp.units.unit import Unit
-from rhoknp.utils.utils import is_comment_line
 
 if TYPE_CHECKING:
     from rhoknp.units.document import Document
@@ -23,7 +22,7 @@ class Sentence(Unit):
         text: 文の文字列．
     """
 
-    EOS_PAT = "EOS"
+    EOS = "EOS"
     SID_PAT = re.compile(r"^(?P<sid>(?P<did>[a-zA-Z\d\-_]+?)(-(\d+))?)$")
     SID_PAT_KWDLC = re.compile(r"^(?P<sid>(?P<did>w\d{6}-\d{10})(-\d+){1,2})$")
     SID_PAT_WAC = re.compile(r"^(?P<sid>(?P<did>wiki\d{8})(-\d{2})(-\d{2})?)$")
@@ -47,8 +46,8 @@ class Sentence(Unit):
         self._phrases: Optional[List[Phrase]] = None
         self._morphemes: Optional[List[Morpheme]] = None
 
-        self.sid: Optional[str] = None
-        self.doc_id: Optional[str] = None
+        self._sent_id: Optional[str] = None
+        self._doc_id: Optional[str] = None
         self.misc_comment: str = ""
 
         self.named_entities: List[NamedEntity] = []
@@ -63,12 +62,17 @@ class Sentence(Unit):
         self.named_entities = []
         if self.need_knp is False:
             for base_phrase in self.base_phrases:
-                if fstring := base_phrase.features.get("NE", None):
+                if fstring := base_phrase.features.get("NE"):
                     assert isinstance(fstring, str)
                     candidate_morphemes = self.morphemes[: base_phrase.morphemes[-1].index + 1]
                     if named_entity := NamedEntity.from_fstring(fstring, candidate_morphemes):
                         self.named_entities.append(named_entity)
 
+    def __eq__(self, other: Any) -> bool:
+        if isinstance(other, Sentence) is False:
+            return False
+        return self._sent_id == other._sent_id and self.text == other.text
+
     @property
     def global_index(self) -> int:
         """文書全体におけるインデックス．"""
@@ -95,6 +99,82 @@ class Sentence(Unit):
             return self._morphemes
         return None
 
+    @property
+    def doc_id(self) -> str:
+        """文書 ID．
+
+        Raises:
+            AttributeError: 文書 IDにアクセスできない場合．
+        """
+        if self._doc_id is None:
+            raise AttributeError("doc_id has not been set")
+        return self._doc_id
+
+    @doc_id.setter
+    def doc_id(self, doc_id: str) -> None:
+        """文書 ID．
+
+        Args:
+            doc_id: 文書 ID．
+        """
+        self._doc_id = doc_id
+
+    @property
+    def did(self) -> str:
+        """文書 ID（doc_id のエイリアス）．
+
+        Raises:
+            AttributeError: 文書 IDにアクセスできない場合．
+        """
+        return self.doc_id
+
+    @did.setter
+    def did(self, did: str) -> None:
+        """文書 ID（doc_id のエイリアス）．
+
+        Args:
+            did: 文書 ID．
+        """
+        self.doc_id = did
+
+    @property
+    def sent_id(self) -> str:
+        """文 ID．
+
+        Raises:
+            AttributeError: 文 IDにアクセスできない場合．
+        """
+        if self._sent_id is None:
+            raise AttributeError("sid has not been set")
+        return self._sent_id
+
+    @sent_id.setter
+    def sent_id(self, sid: str) -> None:
+        """文 ID．
+
+        Args:
+            sid: 文 ID．
+        """
+        self._sent_id = sid
+
+    @property
+    def sid(self) -> str:
+        """文 ID（sent_id のエイリアス）．
+
+        Raises:
+            AttributeError: 文 IDにアクセスできない場合．
+        """
+        return self.sent_id
+
+    @sid.setter
+    def sid(self, sid: str) -> None:
+        """文 ID（sent_id のエイリアス）．
+
+        Args:
+            sid: 文 ID．
+        """
+        self.sent_id = sid
+
     @property
     def document(self) -> "Document":
         """文書．
@@ -123,7 +203,7 @@ class Sentence(Unit):
             AttributeError: 解析結果にアクセスできない場合．
         """
         if self._clauses is None:
-            raise AttributeError("not available before applying KNP")
+            raise AttributeError("clauses have not been set")
         return self._clauses
 
     @clauses.setter
@@ -148,7 +228,7 @@ class Sentence(Unit):
             return self._phrases
         elif self._clauses is not None:
             return [phrase for clause in self.clauses for phrase in clause.phrases]
-        raise AttributeError("not available before applying KNP")
+        raise AttributeError("phrases have not been set")
 
     @phrases.setter
     def phrases(self, phrases: List[Phrase]) -> None:
@@ -183,7 +263,7 @@ class Sentence(Unit):
             return [morpheme for clause in self.clauses for morpheme in clause.morphemes]
         elif self._phrases is not None:
             return [morpheme for phrase in self.phrases for morpheme in phrase.morphemes]
-        raise AttributeError("not available before applying Jumanpp")
+        raise AttributeError("morphemes have not been set")
 
     @morphemes.setter
     def morphemes(self, morphemes: List[Morpheme]) -> None:
@@ -200,7 +280,7 @@ class Sentence(Unit):
     def comment(self) -> str:
         """コメント行．"""
         ret = ""
-        if sid := self.sid:
+        if sid := self._sent_id:
             ret += f"S-ID:{sid} "
         if misc := self.misc_comment:
             ret += f"{misc} "
@@ -251,9 +331,7 @@ class Sentence(Unit):
             post_init: インスタンス作成後の追加処理を行うなら True．
 
         Example:
-
             >>> from rhoknp import Sentence
-            <BLANKLINE>
             >>> text = "天気が良かったので散歩した。"
             >>> sent = Sentence(text)
         """
@@ -262,7 +340,7 @@ class Sentence(Unit):
         for line in text.split("\n"):
             if line.strip() == "":
                 continue
-            if is_comment_line(line):
+            if cls.is_comment_line(line):
                 sentence.comment = line
             else:
                 text_lines.append(line)
@@ -285,7 +363,6 @@ class Sentence(Unit):
         Example:
 
             >>> from rhoknp import Sentence
-            <BLANKLINE>
             >>> jumanpp_text = \"\"\"
             ... # S-ID:1
             ... 天気 てんき 天気 名詞 6 普通名詞 1 * 0 * 0 "代表表記:天気/てんき カテゴリ:抽象物"
@@ -305,18 +382,23 @@ class Sentence(Unit):
         for line in jumanpp_text.split("\n"):
             if not line.strip():
                 continue
-            if is_comment_line(line):
+            if cls.is_comment_line(line):
                 sentence.comment = line
                 continue
-            elif line.startswith("@") and not line.startswith("@ @"):
-                # homograph
-                pass
-            elif jumanpp_lines:
-                morphemes.append(Morpheme.from_jumanpp("\n".join(jumanpp_lines)))
-                jumanpp_lines = []
-            jumanpp_lines.append(line)
-            if line.strip() == cls.EOS_PAT:
+            if Morpheme.is_morpheme_line(line):
+                if jumanpp_lines:
+                    morphemes.append(Morpheme.from_jumanpp("\n".join(jumanpp_lines)))
+                    jumanpp_lines = []
+                jumanpp_lines.append(line)
+                continue
+            if Morpheme.is_homograph_line(line):
+                jumanpp_lines.append(line)
+                continue
+            if line.strip() == cls.EOS:
+                if jumanpp_lines:
+                    morphemes.append(Morpheme.from_jumanpp("\n".join(jumanpp_lines)))
                 break
+            raise ValueError(f"malformed line: {line}")
         sentence.morphemes = morphemes
         if post_init is True:
             sentence.__post_init__()
@@ -336,7 +418,6 @@ class Sentence(Unit):
         Example:
 
             >>> from rhoknp import Sentence
-            <BLANKLINE>
             >>> knp_text = \"\"\"
             ... # S-ID:1
             ... * 1D
@@ -358,7 +439,7 @@ class Sentence(Unit):
         """
         lines = knp_text.split("\n")
         sentence = cls()
-        has_clause_boundary = any("節-区切" in line for line in lines if line.startswith("+"))
+        has_clause_boundary = any("節-区切" in line for line in lines if BasePhrase.is_base_phrase_line(line))
         clauses: List[Clause] = []
         phrases: List[Phrase] = []
         child_lines: List[str] = []
@@ -366,28 +447,34 @@ class Sentence(Unit):
         for line in lines:
             if not line.strip():
                 continue
-            if is_comment_line(line):
+            if cls.is_comment_line(line):
                 sentence.comment = line
                 continue
-            if line.startswith(";;"):
-                raise Exception(f"Error: {line}")
-            if line.startswith("+") and "節-区切" in line:
-                is_clause_end = True
-            if line.strip() == cls.EOS_PAT:
-                if has_clause_boundary is True:
-                    clauses.append(Clause.from_knp("\n".join(child_lines)))
-                else:
-                    phrases.append(Phrase.from_knp("\n".join(child_lines)))
-                break
-            if line.startswith("*"):
-                if is_clause_end is True:
+            if Phrase.is_phrase_line(line):
+                if has_clause_boundary and is_clause_end and child_lines:
                     clauses.append(Clause.from_knp("\n".join(child_lines)))
                     child_lines = []
                     is_clause_end = False
                 elif has_clause_boundary is False and child_lines:
                     phrases.append(Phrase.from_knp("\n".join(child_lines)))
                     child_lines = []
-            child_lines.append(line)
+                child_lines.append(line)
+                continue
+            if BasePhrase.is_base_phrase_line(line):
+                if "節-区切" in line:
+                    is_clause_end = True
+                child_lines.append(line)
+                continue
+            if Morpheme.is_morpheme_line(line) or Morpheme.is_homograph_line(line):
+                child_lines.append(line)
+                continue
+            if line.strip() == cls.EOS:
+                if has_clause_boundary:
+                    clauses.append(Clause.from_knp("\n".join(child_lines)))
+                else:
+                    phrases.append(Phrase.from_knp("\n".join(child_lines)))
+                break
+            raise ValueError(f"malformed line: {line}")
         if has_clause_boundary is True:
             sentence.clauses = clauses
         else:
@@ -408,8 +495,9 @@ class Sentence(Unit):
             Optional[str]: Sentence id if exists; otherwise, None.
             str: The rest of the comment line.
         """
+        assert comment.startswith("#")
         if match_sid := re.match(r"# S-ID: ?(\S*)( .+)?$", comment):
-            sid_string = match_sid.group(1)
+            sid_string = match_sid[1]
             match = (
                 Sentence.SID_PAT_KWDLC.match(sid_string)
                 or Sentence.SID_PAT_WAC.match(sid_string)
@@ -418,12 +506,11 @@ class Sentence(Unit):
             if match is None:
                 raise ValueError(f"unsupported S-ID format: {sid_string}")
             return (
-                match.group("did"),
-                match.group("sid"),
-                match_sid.group(2).lstrip() if match_sid.group(2) else "",
+                match["did"],
+                match["sid"],
+                match_sid[2].lstrip() if match_sid[2] else "",
             )
-        assert comment.startswith("# ")
-        return None, None, comment[2:]
+        return None, None, comment.lstrip("#").lstrip(" ")
 
     def to_raw_text(self) -> str:
         """生テキストフォーマットに変換．"""
@@ -442,7 +529,7 @@ class Sentence(Unit):
         ret = ""
         if self.comment != "":
             ret += self.comment + "\n"
-        ret += "".join(morpheme.to_jumanpp() for morpheme in self.morphemes) + self.EOS_PAT + "\n"
+        ret += "".join(morpheme.to_jumanpp() for morpheme in self.morphemes) + self.EOS + "\n"
         return ret
 
     def to_knp(self) -> str:
@@ -455,7 +542,7 @@ class Sentence(Unit):
         if self.comment != "":
             ret += self.comment + "\n"
         ret += "".join(child.to_knp() for child in self._clauses or self.phrases)
-        ret += self.EOS_PAT + "\n"
+        ret += self.EOS + "\n"
         return ret
 
     def reparse(self) -> "Sentence":
@@ -470,7 +557,14 @@ class Sentence(Unit):
             return Sentence.from_jumanpp(self.to_jumanpp())
         return Sentence.from_raw_text(self.to_raw_text())
 
-    def __eq__(self, other: Any) -> bool:
-        if isinstance(other, Sentence) is False:
-            return False
-        return self.sid == other.sid and self.text == other.text
+    @staticmethod
+    def is_comment_line(line: str) -> bool:
+        """コメント行なら True を返す．
+
+        Args:
+            line: 解析結果の一行．
+
+        .. note::
+            JUMAN/KNP では # から始まる行がコメントとみなされる．
+        """
+        return line.startswith("#") and not Morpheme.is_morpheme_line(line)
